package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@(!`0````````````,`/@`!````L",```````!``````````#"S````
M`````````$``.``)`$``'@`=``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````!"C````````$*,`````````
M`"````````$````&````<*T```````!PK2```````'"M(```````H`0`````
M```X%0``````````(````````@````8```"8K0```````)BM(```````F*T@
M```````@`@```````"`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````")P````````(G`````````B<````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````'"M````````<*T@``````!PK2``
M`````)`"````````D`(````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````,````"``````````0`
M```4`````P```$=.50`!!WBS*WFU#2'%YG[N_?E.[XF5Q6$```!E````````
M````````````!```````````````-0``````````````)@```!P`````````
M/`````D```!3`````````!4```!&````1P```#X```!6````8@````8````]
M```````````````#````60```$```````````````$H```!1````30``````
M````````9````$D`````````+P`````````W`````````$X```!8````10``
M`#@`````````80```%P`````````%`````<``````````````%`````C````
M,0```"<```````````````@`````````&``````````````````````````!
M````(0````L```!!````5````#\``````````````%H```!,````*0```%4`
M``!(````,P```#``````````0@```````````````````%L```!+````````
M`"H```!2````,@````P````V`````@``````````````````````````````
M``````````````````````````````````````````!=````````````````
M`````````````````````````````````````````&,``````````````!8`
M``````````````````!@````$P```!D````:````$@````````!>````5P``
M`"4`````````0P``````````````)```````````````%P```"T````=````
M````````````````*````"P`````````(@``````````````.@`````````Y
M````"@```%\````[````-````"L``````````````````````````````!``
M```-````+@`````````%````&P```!X````?`````````"``````````````
M`!$````.````````````````````3P`````````````````````````/````
M````````````````1```````````````$0```$,````$````"````"`<$``%
M0`2&*`)``)"&`(""*0`@22`$";BB&4VZ!`8*`````$,```!'````2P```$P`
M``!3````5````%8```!:````6P````````!=````8````&(```!C````````
M``````!NQ=\?ZM/O#L[>1RUK?YI\+L6;MB#_Y`ZXC?$.U634?-EQ6!SB1\8!
MK$OCP/+;TQVZXY)\PN4_+/JA;&"S`8MO:PE#UF:OS&;%N9Q`0D75[,2)!9"(
M!W#3.?*+'`T4XI[:S>.>,V+;[0PZEPM6I)N6I]VC:WZIG)O19<YMX:<""@J*
M$%>CX/M)``````````````````````````````````````P!```2````````
M`````````````````.(!```2`````````````````````````%@"```2````
M`````````````````````#8"```2``````````````````````````P````@
M`````````````````````````%\"```2`````````````````````````.L"
M```2`````````````````````````*\````2````````````````````````
M`'0"```2`````````````````````````'X!```2````````````````````
M`````-,"```2`````````````````````````,L"```2````````````````
M`````````'\````2`````````````````````````)0#```2````````````
M``````````````<!```2`````````````````````````)<"```2````````
M`````````````````(D"```2`````````````````````````$<"```2````
M`````````````````````.0"```2``````````````````````````$#```2
M`````````````````````````&(!```2`````````````````````````#`!
M```2`````````````````````````+T````2````````````````````````
M`*P!```2``````````````````````````\"```2````````````````````
M`````#X"```2`````````````````````````!\"```2````````````````
M`````````)D!```2`````````````````````````&T"```2````````````
M`````````````-T!```2`````````````````````````$4#```2````````
M`````````````````#X#```2`````````````````````````#X!```2````
M`````````````````````/0"```2`````````````````````````"@````@
M`````````````````````````*L"```2`````````````````````````%\`
M```2`````````````````````````/L!```2````````````````````````
M`*4!```2`````````````````````````(X````2````````````````````
M`````)H````2`````````````````````````%<!```2````````````````
M`````````!T!```2`````````````````````````%$````2````````````
M`````````````!$!```2`````````````````````````+("```2````````
M`````````````````(X!```2`````````````````````````.L````2````
M`````````````````````&4"```2`````````````````````````-8!```2
M`````````````````````````"\#```2``````````````````````````@#
M```2`````````````````````````'`!```2````````````````````````
M`&X````2`````````````````````````#<#```2````````````````````
M`````(("```2`````````````````````````,\````2````````````````
M`````````$X!```2`````````````````````````,`"```2````````````
M`````````````#$"```2`````````````````````````/,!```2````````
M`````````````````)T"```2`````````````````````````#<````@````
M`````````````````````'L"```2`````````````````````````)`"```2
M`````````````````````````"$#```2`````````````````````````)T#
M```2``\`H%H```````!W`````````&L#```2`!``M%L`````````````````
M`,D#```2``\`0$H```````!D#````````%(#```2``\`@"$````````M`@``
M`````'$#```2``\`P$(````````%`````````$@$```2``\`T$(````````:
M`@```````$($```2``P`F!T``````````````````'4$```2``\`L%8`````
M``#M`P```````#0$```0`!L`$+(@`````````````````+`#```2``\`\$0`
M```````J`````````.,#```1`!$`P%L````````$`````````+<!```1`!8`
M@*T@```````3`````````"($```0`!L`J,(@`````````````````$`$```2
M``\`<$$````````P`````````%4$```2``\`T$@```````!L`0```````&<$
M```2``\`($@```````!T`````````-8#```0`!H`\+$@````````````````
M`+T#```2``\`($4```````#L`````````%<#```1`!L`2+(@```````(````
M`````*D#```0`!H`$+(@`````````````````%@#```A`!L`2+(@```````(
M`````````!@$```1`!H`"+(@```````(`````````-T"```1`!L`8+(@````
M```(`````````&$#```2``\`L%L````````"``````````@$```2``\`0%L`
M``````!E`````````-P#```2``\`L",````````K`````````-@#```@`!H`
M\+$@`````````````````/P````1`!L`(+(@```````$`````````%D#```A
M`!L`2+(@```````(`````````((#```2``\`H$@````````D`````````!(#
M```B`````````````````````````/(#```2``\`\$$```````#!````````
M`-X````1`!L`0+(@```````!`````````"<$```2``\`$$8````````#`@``
M``````!L:6)P97)L+G-O`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?
M7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?
M<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L
M7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!0
M97)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R
M;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO
M<GE?=W)A<`!L:6)P=&AR96%D+G-O+C``;W!E;C8T`')E860`7U]E<G)N;U]L
M;V-A=&EO;@!L<V5E:S8T`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;&EB
M8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!C;&]S961I
M<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H
M<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?
M9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O
M<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M
M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R
M:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M
M86EN`%]?96YV:7)O;@!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE
M8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A
M=&$`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A
M=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C
M`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V5N9`!P87)?:6YI=%]E;G8`
M7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI
M8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)
M0D-?,BXR+C4`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'
M3$E"0U\R+C0`+W5S<B]L:6(O<&5R;#4O-2XR-BXQ+W@X-E\V-"UL:6YU>"UT
M:')E860M;75L=&DO0T]210`````"``,``@`"`````@`"`````@````(``@``
M``(````"``(`!``"``(````````````#``(`!0````(``P`"``(````&````
M!P````,``@`````````````````&```````"``,``@`"```````"``(`````
M``(``@`#``8````"``(`!@`!``$``0`!``$``0`!``$``0`!``$````!``$`
M`0`!``$``0`"``$``@`!``(``0`!``$``0````(``0`"``$````!```````!
M``$`Q@$``!`````@````=1II"0```P"+!`````````$`!0`5`@``$```````
M``"4D98&```'`)<$```0````=!EI"0``!@"B!```$````'(9:0D```4`K@0`
M`!`````4:6D-```$`+H$```0````=1II"0```@"+!````````'"M(```````
M"`````````"P)````````'BM(```````"`````````!P)````````/BQ(```
M````"`````````#XL2````````BR(```````"``````````(7P```````+BO
M(```````!@````4``````````````,"O(```````!@````H`````````````
M`,BO(```````!@```!\``````````````-"O(```````!@```",`````````
M`````-BO(```````!@```"L``````````````."O(```````!@```#8`````
M`````````.BO(```````!@```#\``````````````/"O(```````!@```&$`
M`````````````("M(```````!0```$X``````````````""R(```````!0``
M`%X``````````````$"R(```````!0```&,``````````````$BR(```````
M!0```%4``````````````&"R(```````!0```%D``````````````!BP(```
M````!P````$``````````````""P(```````!P````(``````````````"BP
M(```````!P````,``````````````#"P(```````!P````0`````````````
M`#BP(```````!P````8``````````````$"P(```````!P````<`````````
M`````$BP(```````!P````@``````````````%"P(```````!P````D`````
M`````````%BP(```````!P````L``````````````&"P(```````!P````P`
M`````````````&BP(```````!P````T``````````````'"P(```````!P``
M``X``````````````'BP(```````!P````\``````````````("P(```````
M!P```!```````````````(BP(```````!P```!$``````````````)"P(```
M````!P```!(``````````````)BP(```````!P```!,``````````````*"P
M(```````!P```!0``````````````*BP(```````!P```!4`````````````
M`+"P(```````!P```!8``````````````+BP(```````!P```!<`````````
M`````,"P(```````!P```!@``````````````,BP(```````!P```!D`````
M`````````-"P(```````!P```!H``````````````-BP(```````!P```!L`
M`````````````."P(```````!P```!P``````````````.BP(```````!P``
M`!T``````````````/"P(```````!P```!X``````````````/BP(```````
M!P```"````````````````"Q(```````!P```"$```````````````BQ(```
M````!P```"(``````````````!"Q(```````!P```"0``````````````!BQ
M(```````!P```"4``````````````""Q(```````!P```"8`````````````
M`"BQ(```````!P```"<``````````````#"Q(```````!P```"@`````````
M`````#BQ(```````!P```"D``````````````$"Q(```````!P```"H`````
M`````````$BQ(```````!P```"P``````````````%"Q(```````!P```"T`
M`````````````%BQ(```````!P```"X``````````````&"Q(```````!P``
M`"\``````````````&BQ(```````!P```#```````````````'"Q(```````
M!P```#$``````````````'BQ(```````!P```#(``````````````("Q(```
M````!P```#,``````````````(BQ(```````!P```#0``````````````)"Q
M(```````!P```#4``````````````)BQ(```````!P```#<`````````````
M`*"Q(```````!P```#@``````````````*BQ(```````!P```#D`````````
M`````+"Q(```````!P```#H``````````````+BQ(```````!P```#L`````
M`````````,"Q(```````!P```#P``````````````,BQ(```````!P```#T`
M`````````````-"Q(```````!P```#X``````````````-BQ(```````!P``
M`$```````````````."Q(```````!P```$$``````````````.BQ(```````
M!P```$(``````````````$B#[`A(BP4MDB``2(7`=`+_T$B#Q`C#`/\U4I(@
M`/\E5)(@``\?0`#_)5*2(`!H`````.G@_____R5*DB``:`$```#IT/____\E
M0I(@`&@"````Z<#_____)3J2(`!H`P```.FP_____R4RDB``:`0```#IH/__
M__\E*I(@`&@%````Z9#_____)2*2(`!H!@```.F`_____R4:DB``:`<```#I
M</____\E$I(@`&@(````Z6#_____)0J2(`!H"0```.E0_____R4"DB``:`H`
M``#I0/____\E^I$@`&@+````Z3#_____)?*1(`!H#````.D@_____R7JD2``
M:`T```#I$/____\EXI$@`&@.````Z0#_____)=J1(`!H#P```.GP_O___R72
MD2``:!````#IX/[___\ERI$@`&@1````Z=#^____)<*1(`!H$@```.G`_O__
M_R6ZD2``:!,```#IL/[___\ELI$@`&@4````Z:#^____):J1(`!H%0```.F0
M_O___R6BD2``:!8```#I@/[___\EFI$@`&@7````Z7#^____)9*1(`!H&```
M`.E@_O___R6*D2``:!D```#I4/[___\E@I$@`&@:````Z4#^____)7J1(`!H
M&P```.DP_O___R5RD2``:!P```#I(/[___\E:I$@`&@=````Z1#^____)6*1
M(`!H'@```.D`_O___R5:D2``:!\```#I\/W___\E4I$@`&@@````Z>#]____
M)4J1(`!H(0```.G0_?___R5"D2``:"(```#IP/W___\E.I$@`&@C````Z;#]
M____)3*1(`!H)````.F@_?___R4JD2``:"4```#ID/W___\E(I$@`&@F````
MZ8#]____)1J1(`!H)P```.EP_?___R42D2``:"@```#I8/W___\E"I$@`&@I
M````Z5#]____)0*1(`!H*@```.E`_?___R7ZD"``:"L```#I,/W___\E\I`@
M`&@L````Z2#]____)>J0(`!H+0```.D0_?___R7BD"``:"X```#I`/W___\E
MVI`@`&@O````Z?#\____)=*0(`!H,````.G@_/___R7*D"``:#$```#IT/S_
M__\EPI`@`&@R````Z<#\____);J0(`!H,P```.FP_/___R6RD"``:#0```#I
MH/S___\EJI`@`&@U````Z9#\____):*0(`!H-@```.F`_/___R6:D"``:#<`
M``#I</S___\EDI`@`&@X````Z6#\____)8J0(`!H.0```.E0_/___R6"D"``
M:#H```#I0/S___\E>HX@`&:0``````````!54TB#[#B)?"0<2(ET)!!(C7PD
M'$B)5"0(2(UT)!!(C50D"&1(BP0E*````$B)1"0H,<#H"/[__TB+-1F.(`!(
MBST:CB``2(GRZ%(Y``"`/6N0(```=2_H-/W__TB%P$B)!;J@(``/A+<!``!(
MB<?H;/S__XL])I`@`.C1_?__QH#1"````(L]%)`@`.B__?__@(BJ!````HL]
M`I`@`.BM_?__@(BJ!````8M$)!R->`5(N/________\?2&/_2#G'#X<B`0``
M2,'G`TB-'6D[``#H^?S__TB+?"002(D%):`@`,<%(Z`@``0```!(BQ=(B5@(
M2(T=0SL``$B)6!A(B1!(BQ5_CR``2(E0$(M4)!R#^@%$C4H$?BU$C4H$2(/'
M"+X%````9@\?A```````3(L'2&/.@\8!2(/'"$$Y\4R)1,CX=>E(BSW2GR``
M36/)2(TUR!X``(/"`T4QP$K'1,CX`````$B)P>AA_?__A<")PW1D2(L]I)\@
M`$B-;"0DZ-K[__](C3U7.0``,<!(B>[HN1<``$B%P'0J2(L]?9\@`.A8^___
MZ//\__^)V$B+7"0H9$@S'"4H````=5](@\0X6UW#2(L]2Y\@`$B%_W0LZ$DW
M``#KPTB+/4"?(`#HB_W__XG#ZXQ(C340BB``2(T]GS@``#'`Z(+\__](C3V4
M.```2(GNZ$,7``!(A<!(B<=(B07^GB``=(#KM.@-^___OP$```#H8_W__P\?
M`#'M28G17DB)XDB#Y/!05$R-!>HW``!(C0US-P``2(T]K/W___\5[HL@`/0/
M'T0``$B-/2F.(`!52(T%(8X@`$@Y^$B)Y7092(L%NHL@`$B%P'0-7?_@9BX/
M'X0``````%W#9F8N#Q^$```````/'P!(C3WIC2``2(TUXHT@`%5(*?Y(B>5(
MP?X#2(GP2,'H/T@!QDC1_G082(L%F8L@`$B%P'0,7?_@9@\?A```````7<-F
M9BX/'X0```````\?`(`]\8T@``!U+TB#/6^+(```54B)Y70,2(L]:HT@`.C=
M_/__Z$C____&!<F-(``!7<,/'X``````\\-F#Q]$``!52(GE7>EF____9@\?
M1```05=!5DR-3SA!54%413'`55-(@>R8`@``9$B+!"4H````2(F$)(@"```Q
MP$B)X6:00XL$`4N+-`$/R$B)\HG`2,'J($J)!$%(B?!(P>XX2,'H*"4`_P``
M2`GP2(G62,'B"$C!YAB!X@``_P")]D@)\$@)T$J)1$$(28/`"$F#^$!UKDB-
ML0`"```/'X``````2(M!:$@S04!(@\$(2#-!"$@S0?A(C10`2,'H'T@)T(/@
M_TB)07A(.?%UU4R+%TB+7Q!(BW<@2(MO&$R+3PA,B=!,B=)(P>H;2,'@!4@)
MT`,$)(V4,)EY@EI(B=A(BW0D"$@QZ$PAR$@QZ$B-M#69>8):1(TL`DR)RDR)
MR$C!Z`)(P>(>2`G"2(G838GHB=%)P>@;2#'(3"'02#'82`'P3(GN2,'F!4P)
MQD2-)`9,B=9,B=!(P>8>2,'H`D@)\$B+="0038GC2#'"2<'K&T&)P$PAZDB-
MM#.9>8):2#'*2`'R3(GF2,'F!4P)WD2-'!9,B>Y(BU0D&$G![0)(P>8>3`GN
M2#'P2(V4$9EY@EI,B=E,(>!!B?9,,<!(P>D;2`'03(G:2,'B!4@)RDR)X4G!
M[`)$C2P"2,'A'DB+5"0@3`GA2(GP2#'(3(GN08G,3"'828V4$)EY@EI(P>X;
M3#'P2`'03(GJ2,'B!4@)\D2-!`),B=I(BT0D*$G!ZP)(P>(>3`G:3(G&2#'1
M28V$!IEY@EI(P>X;3"'I08G33#'A2`'!3(G`2,'@!4@)\$2--`A,B>A(BTPD
M,$G![0)(P>`>3`GH3(GV2#'"28V,#)EY@EI!B<5,(<),,=I(`<I,B?%(P>$%
M2,'N&T@)\4R)QDG!Z`)$C2012,'F'DB+5"0X3`G&2#'P3(GA08GP3"'P28V4
M$YEY@EI(P>D;3#'H2`'03(GB2,'B!4@)RDR)\4G![@)$C1P"2,'A'DB+5"1`
M3`GQ2(GP2#'(3(G>08G.3"'@28V4%9EY@EI(P>X;3#'`2`'03(G:2,'B!4@)
M\D2-+`),B>)(BT0D2$G![`)(P>(>3`GB3(GN2#'128V$`)EY@EI(P>X;3"'9
M08G43#'Q2`'!3(GH2,'@!4@)\$2-!`A,B=A(BTPD4$G!ZP)(P>`>3`G83(G&
M2#'"28V,#IEY@EI(P>X;3"'J08G#3#'B2`'*3(G!2,'A!4@)\4R)[DG![0)$
MC3012,'F'DB+5"183`GN2#'P3(GQ08GU3"'`28V4%)EY@EI(P>D;3#'82`'0
M3(GR2,'B!4@)RDR)P4G!Z`)$C20"2,'A'DB+5"1@3`G!2(GP2#'(3(GF08G(
M28V4$YEY@EI,(?!(P>X;3#'H2`'03(GB2,'B!4@)\D2-'`),B?)(BT0D:$C!
MXAY)P>X"3`GR3(G>2#'128V$!9EY@EI(P>X;3"'A08G63#'!2`'!3(G82,'@
M!4@)\$2-+`A,B>!(BTPD<$G![`)(P>`>3`G@3(GN2#'"28V,")EY@EI(P>X;
M3"':08G$3#'R2`'*3(GI2,'A!4@)\4R)WDG!ZP)$C0012,'F'DB+5"1X3`G>
M2#'P3(G!08GS3"'H28V4%IEY@EI(P>D;3#'@2`'03(G"2,'B!4@)RDR)Z4G!
M[0)$C30"2,'A'DB+E"2`````3`GI2(GP2#'(3(GV08G-3"'`28V4%)EY@EI(
MP>X;3#'82`'03(GR2,'B!4@)\D2-)`),B<)(BX0DB````$G!Z`)(P>(>3`G"
M3(GF2#'128V$`YEY@EI(P>X;3"'Q08G03#'I2`'!3(G@2,'@!4@)\$B+M"20
M````1(T<"$R)\$G![@)(P>`>3`GP28VT-9EY@EI-B=U(,<))P>T;B<%,(>),
M,<)(`?),B=Y(P>8%3`GNB?9(`?),B>9)P>P"2,'F'D&)U4P)YDR+I"28````
M2#'P3"'83XV$()EY@EI(,<A-B>Q)P>P;3`'`38GH2<'@!4T)X$6)P$P!P$V)
MV$G!ZP))P>`>08G$30G828GSB?9-,<-(`[0DJ````$0QVDR+G"2@````2HV,
M&:'KV6Y-B>-)P>L;2`'13(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,
M">I-B<5%B<!),=5,`X0DL````$0QZ$V)W4B-M`:AZ]EN3(G82<'M&TC!X`5,
M">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1$,>%-B>Q(`Y0DN```
M`$V-A`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G9
M28GSB?9),<M(`[0DP````$0QV$V)XTB-E`*AZ]EN3(G@2<'K&TC!X`5,"=B)
MP$@!PDR)Z$G![0)(P>`>08G33`GH28G-B<E),<5(`XPDR````$4QZ$V)W4Z-
MA`:AZ]EN3(G>2<'M&TC!Y@5,">Z)]DP!QDV)X$G![`))P>`>08GU30G@28G$
MB<!-,<1$,>)-B>Q(C8P1H>O9;DR)ZDC!X@5)P>P;2`.$)-````!,">*)TD@!
MT4R)VDG!ZP)(P>(>08G,3`G:38G#18G`23'33`.$)-@```!$,=Y-B>-(C;0P
MH>O9;DR)X$G!ZQM(P>`%3`G8B<!(`?!,B>Y)P>T"2,'F'D&)PTP)[DF)U8G2
M23'U2`.4).````!$,>E-B=U-C80(H>O9;DR)V4G![1M(P>$%3`GIB<E)`<A,
MB>%)P>P"2,'A'D6)Q4P)X4F)](GV23',1#'@38GL2(V4`J'KV6Y,B>A)P>P;
M2,'@!4P)X(G`2`'"3(G82`.T).@```!)P>L"2,'@'D&)U$P)V$F)RXG)23'#
M2`.,)/````!%,=A-B>-.C80&H>O9;DR)YDG!ZQM(P>8%3`G>B?9,`<9-B>A)
MP>T"2<'@'D&)\TT)Z$F)Q8G`33'%2`.$)/@```!$,>I-B=U(C8P1H>O9;DR)
MVDG![1M(P>(%3`GJB=)(`=%,B>))P>P"2,'B'D&)S4P)XDV)Q$6)P$DQU$0Q
MYDV)[$B-M#"AZ]EN3(GH2<'L&TC!X`5,">")P$@!\$R)WDC!YAY)P>L"3`.$
M)``!``!,"=Y)B=-!B<1),?.)TD@#E"0(`0``1#'938GC38V$"*'KV6Y,B>%)
MP>L;2,'A!4P)V8G)20'(3(GI2<'M`DC!X1Y%B<-,">E)B?6)]DDQS4@#M"00
M`0``1#'H38G=2(V4`J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'"3(G@2<'L`DC!
MX!Y!B=5,">!)B<R)R4DQQ$4QX$V)[$Z-A`:AZ]EN3(GN2<'L&TC!Y@5,">:)
M]DP!QDV)V$G!ZP))P>`>08GT30G82`.,)!@!``!)B<--,<.)P$@#A"0@`0``
M1#':38GC2<'K&TB-C!&AZ]EN3(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!
MB<M,">I-B<5%B<!),=5,`X0D*`$``$0Q[DV)W4B-M#"AZ]EN3(G82<'M&TC!
MX`5,">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1(`Y0D,`$``$0Q
MX4V)[$V-A`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$
M3`G928GSB?9),<M$,=A-B>-(`[0D.`$``$B-E`*AZ]EN3(G@2<'K&TC!X`5,
M"=A$C1P03(GH2<'M`DC!X!Y,">A)B<V)R4DQQ8G"13'H38G=3HV$!J'KV6Y,
MB=Y)P>T;2,'F!4P)[DR+K"1``0``1HTT!DV)X$G![`))P>`>30G@3`G`1(G&
M28G$2(G02"'P32'<20G$N-R\&X])`<5,`>E-B?5)`<Q,B?%)P>T;2,'A!4P)
MZ4F)]4$!S$R)V4G!ZP)(P>$>3`G908G+20G(32'P32'=30GH3(NL)$@!``!)
M`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B'DP)\DV)
MWD&)T$@)T4TAQDPAX4P)\4R+M"10`0``20'&3`'V38GN2`'Q3(GN2<'N&TC!
MY@5,"?9$C30.3(GF2<'L`DC!YAY,">9-B<2)\4@)\DDAS$PAZDP)XDR+I"18
M`0``20'$30'C38GT3`':38GS2<'C!4G![!M-">-%C20338GK2<'M`DG!XQY-
M">M)B<U$B=I,"=Y)(=5,(?9,">Y,BZPD8`$``$D!Q4T!Z$V)Y4P!QDV)X$G!
M[1M)P>`%30GH18TL,$V)\$G![@))P>`>30GP28G61(G&30G#22'V32'C30GS
M3(NT)&@!``!)`<9,`?%-B>Y)`<M,B>E)P>X;2,'A!4P)\4:--!E,B>%)P>P"
M2,'A'DP)X4F)]$&)RTD)R$TAZ$TAW$T)X$R+I"1P`0``20'$3`'B38GT20'0
M3(GR2<'L&TC!X@5,">)&C20"3(GJ2<'M`DC!XAY,">I-B=U!B=!("=%-(<5,
M(?%,">E,BZPD>`$``$D!Q4P![DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL#DR)
M]DG![@)(P>8>3`GV38G&B?%("?))(<Y,(>),"?),B[0D@`$``$D!QDT!\TV)
M[DP!VDV)ZTG!XP5)P>X;30GS18TT$TV)XTG![`))P>,>30GC28G,1(G:3`G>
M22'43"'N3`GF3(ND)(@!``!)`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)X$6-
M)#!-B>A)P>T"2<'@'DT)Z$F)U42)QDT)PTDA]4TA\TT)ZTR+K"20`0``20'%
M3`'I38GE20'+3(GA2<'M&TC!X05,">E&C2P93(GQ2<'N`DC!X1Y,"?%)B?9)
M"<A!B<M-(=Y-(>!-"?!,B[0DF`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(P>(%
M3`GR1HTT`DR)XDG![`)(P>(>3`GB38G<08G02`G132'$3"'I3`GA3(ND)*`!
M``!)`<1,`>9-B?1(`?%,B?9)P>P;2,'F!4P)YD2-)`Y,B>Y)P>T"2,'F'DP)
M[DV)Q8GQ2`GR22'-3"'R3`GJ3(NL)*@!``!)`<5-`>M-B>5,`=I-B>-)P>T;
M2<'C!4T)ZT6-+!--B?-)P>X"2<'C'DT)\TF)SD2)VDP)WDDAUDPAYDP)]DR+
MM"2P`0``20'&30'P38GN3`'&38GH2<'N&TG!X`5-"?!%C30P38G@2<'L`DG!
MX!Y-">!)B=1$B<9-"<-)(?1-(>M-">-,BZ0DN`$``$D!Q$P!X4V)]$D!RTR)
M\4G![!M(P>$%3`GA1HTD&4R)Z4G![0)(P>$>3`GI28GU08G+20G(32'P32'=
M30GH3(NL),`!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))
MP>X"2,'B'DV)V$P)\D&)UD@)T4TA\$PAX4P)P4R+A"3(`0``20'`3`'&38GH
M2`'Q3(GN2<'H&TC!Y@5,"<9$C00.3(GF2<'L`DC!YAY,B?%,">9!B?1("?),
M(>%,(>I("<I(BXPDT`$``$@!P4D!RTR)P4@#A"38`0``3`':38G#2,'A!4G!
MZQM,"=F)R4P!\$@!RDR)Z4G![0)(P>$>08G33`GI38GE08G/2`G.32']3"'&
M3`GN38G=2`'P3(G>2<'M&TC!Y@5,">Z)]D@!\$R)QDG!Z`)(P>8>08G%20GP
MOM;!8LI,,<$QRDB+C"3@`0``2`'Q20',3(GI3`'B38GL2,'A!4G![!M,">&)
MR4@!RDR)V4C!X1Y)P>L"08G420G+3(G!38GF3#'92<'N&T6)P#'(2(N,).@!
M``!(`?%)`<]*C0PX3(G@2,'@!4P)\(G`3(TT`4R)Z$G![0)(P>`>3(G918G;
M20G%2(N$)/`!``!%B?=,,>DQRDR)^4@!\$C!Z1M,`<!(`<),B?A(P>`%2`G(
M2(N,)/@!``")P$@!PDR)X$G![`)(P>`>2`'Q08G03`G@3`'938GK23'#38G$
M18GM13'>2<'L&TZ-'#%,B<%(P>$%3`GAB<E)`<M,B?E)P>\"2,'A'D6)W$D)
MSTB+C"0``@``2`'Q3`'I28G%B<!-,?U$,>I,C2P13(GB3(GA2,'I&TC!X@5(
M"<I,B<%)P>@"B=)(P>$>20'52(N4)`@"``!,"<%-B?A%B>Y%B?]),<A(`?)%
M,<-(`=!,B?).C0083(GP2,'J&TC!X`5("=!(B<J)R8G`20'`3(G@2<'L`DC!
MX!Y%B<-)"<1(BX0D$`(``$PQXD$QU4R)VD@!\$P!^$D!Q4R)V$C!X`5(P>H;
M2`G03(GR2<'N`HG`2,'B'DD!Q4B+A"08`@``3`GR18GO2`'P2`'(3(GA18GD
M2#'103'(3(GY20'`3(GX2,'I&TC!X`5("<B)P$D!P$R)V$G!ZP)(P>`>18G&
M20G#2(N$)"`"``!,B?%(P>D;2`'P3`'@28G4B=)-,=Q%,>5.C20H3(GP2,'@
M!4@)R$B+C"0H`@``B<!)`<1,B?A)P>\"2`'Q2,'@'D6)Y4P)^$@!RDR)V4@Q
MP46)VT$QR$R)Z4D!T$R)ZDC!Z1M(P>(%2`G*B=))`=!,B?))P>X"2,'B'D6)
MQTD)UDB+E"0P`@``3(GY2,'I&T@!\DP!VDF)PXG`33'S13'<3HT<(DR)^DC!
MX@5("<I,B>E)P>T"B=)(P>$>20'32(N4)#@"``!,">E%B=Q(`?)(`=!,B?)%
MB?9(,<I!,=!,B>))`<!,B>!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B?A)P>\"
M2,'@'D6)Q4D)QTB+A"1``@``2`'P3#'Z3`'P03'33(GJ20'#3(GH2,'J&TC!
MX`5("=!,B>))P>P"B<!(P>(>20'#2(N$)$@"``!,">)%B=Y)B=1(`?!(`<A,
MB?E%B?](,=&)TD$QR$J-#`!,B?!-B?!)P>@;2,'@!4P)P(G`2`'!3(GH2<'M
M`DC!X!Y!B<A)"<5(BX0D4`(``$TQ[$4QXTV)Q$@!\$G![!M,`?A)`<-,B<!(
MP>`%3`G@B<!)`<-,B?!(P>`>2<'N`D6)W$P)\$R+M"18`@``20'V20'63(GJ
M18GM2#'",=%)C10.3(GA38GF2<'N&TC!X05,"?&)R4@!RDR)P4G!Z`)(P>$>
M08G620G(2(N,)&`"``!(`?%,`>E)B<6)P$TQQ44QZTV)]4D!RTR)\4G![1M(
MP>$%3`GIB<E)`<M,B>%)P>P"2,'A'D6)W4D)S$B+C"1H`@``2`'Q2`'(3(G!
M18G`3#'A,<I(C0P03(GH3(GJ2,'J&TC!X`5("=!,B?))P>X"2,'B'HG`20G6
M2(N4)'`"``!(`<&)R$@!\DP!PDV)X$TQ\$4QPTF)P$P!VDF)PTG!X`5)P>L;
M30G828G#2,'H`DG!XQY!`=!,B>I)"<-(BX0D>`(``$C!XAY)P>T"00';20G5
M1(GB3(E?$$@!\$0![4@!PDR)\$B);QA,,>@QP4B-!`I,B<),B<%(P>(%2,'I
M&T4!R$@)RDR)1P@!T$$!PD0#=R!(BX0DB`(``&1(,P0E*````$R)%TR)=R!U
M$DB!Q)@"``!;74%<05U!7D%?P^CBX___9I!!5T%6055!5%532(/L"$B%_P^$
ML0```$R+/5IW(`!-A?\/A*$````/M@>$P'0$/#UU7D4QY$F+'TB%VW0Y28GU
M28G^36/D3(G]#Q^``````$R)XDR)]DB)W^C"XO__A<!U!T*`/",]=$=(@\4(
M2(M=`$B%VW7:2(/$"$B)V%M=05Q!74%>05_##Q^$``````!)B?Q)@\0!00^V
M!"2$P'0$/#UU[T$I_.N,#Q^``````$PI_4J-7",!2,']`T&);0#KM&8/'T0`
M`#';ZZH/'T``55-(B?U(@^P89$B+!"4H````2(E$)`@QP$B-7"0$9I`QP$B)
MWDB)[^@#____2(7`=#9(8U0D!$B+!6IV(`!(C0302(M0"$B%TDB)$'329I!(
M@\`(2(M0"$B%TDB)$'7PZ[YF#Q]$``!(BT0D"&1(,P0E*````'4'2(/$&%M=
MP^B,XO__9F8N#Q^$``````"005=!5D%505154TB)\TB)_4B#["AD2(L$)2@`
M``!(B40D&#'`,<"`/CT/E,!(`<-(B=_H.>+__TB-="0428G$2(GO,<#H5_[_
M_TB%P`^$#@$``$B)QTF)Q>@3XO__3#G@#X/B````3&-T)!1)P>8##[9%`(3`
M#X2M`0``/#T/A*4!``!(B>CK#0\?A```````@/H]=`M(@\`!#[80A-)U\$@I
MZ$B83`,U;'4@`$J-?"`"Z/KB__](A<!)B08/A'L!``!(8U0D%$B+!4IU(`!(
MC4T!2(L4T`^V10`\/8@"=":$P'40ZR!F+@\?A```````/#UT$DB#P0$/MD'_
M2(/"`83`B`)UZL8"/3'`#Q]$```/M@P#B$P"`4B#P`&$R77P,<!(BW0D&&1(
M,S0E*`````^%$0$``$B#Q"A;74%<05U!7D%?PP\?`$B#PP$/MD/_28/%`83`
M08A%_W7LZ\)FD$R+/;%T(`!)@S\`#X2_````3(GX,=+K"P\?A```````1(GJ
M2(/`"$2-:@%(@S@`=>^-<@-(8_9(P>8#BP6OA"``A<!U6TB)]\<%GH0@``$`
M``#H^>'__TB%P`^$?0```$UCQ4R)_DB)QTZ--,4`````3(E$)`A,B?+H@N+_
M_TR+1"0(2(G!2(D%*W0@`$K'1,$(`````$2);"04Z6_^__],B?_H..+__TB%
MP$B)P4B)!0-T(`!T)DUCQ4Z--,4`````Z\D/'T``,<#I=O[__Y"^$````$4Q
M[>E>____N/_____IV_[__^@TX/__#Q]``$%7059!54%455-(@>RX````9$B+
M!"4H````2(F$)*@````QP$B%_W0(@#\`28G^=2](BX0DJ````&1(,P0E*```
M``^%+`$``$B!Q+@```!;74%<05U!7D%?PV8/'T0``.AKW___2(7`2(G#=,1(
MC40D$$B-+<P<``!,C27$'```3(T]P!P``$B)!"1(B=_HC>'__TB%P`^$O```
M`$R-2!.Y`@```$B)[TR)SO.F#Y?`'`"$P'35N0,```!,B<Y,B>?SI@^7P!P`
MA,!TOTR)]TR)3"0(Z$??__],BTPD"$F)Q4R)S^@WW___08U\!0)(8__H:N#_
M_TR+3"0(28G%2(G'38GP3(GY2,?"_____[X!````,<#HQN'__TB+%"2_`0``
M`$R)[NB5WO__@_C_3(GO=!"+1"0H)0#P```]`$```'0JZ!C>__],B>_H\-W_
M_^DV____#Q\`2(G?Z%#?__],B??HJ-[__^G$_O__Z([^___KU.BWWO__#Q^`
M`````%-(B?N+/19R(`#HP=___TB-D``"``!(B=Z_`0```.C=X/__A<!T"3'`
M6\,/'T0``(L]ZG$@`.B5W___BX`8`@``)0#P```]`$```'0=BSW-<2``Z'C?
M__^+@!@"```E`/```#T`H```=;U(B=^^`@```.A)X/__A<`/E,`/ML!;PV9F
M+@\?A```````#Q]``$%6055)B?9!5%5)B?Q32(T]*!L``+K_#P``2('L$!``
M`$B)XTB)WF1(BP0E*````$B)A"0($```,<#H0=W__X7`#XZ)````C5#_1(LM
M/W$@`$ACZH`\+`!T5DACZ$B)ZKXO````2(G?Z&/>__](A<!T1D2)[^C&WO__
M2(GI2(G:3(GF2(G'Z,7?__](BX0D"!```&1(,P0E*````'4[2('$$!```%M=
M05Q!74%>PV:0A=)UJ0\?0`!$B>_H@-[__TR)\DR)YDB)Q^B2W?__Z[M$BRVY
M<"``Z]_H0MW__V:02(/L"(L]IG`@`.A1WO__2(L5.FX@`$B-#6,<``!(C35(
M&@``2(G'2(/$".EPWO__2(/L"(L]=G`@`.@AWO__2(G'Z+G___^+/6-P(`#H
M#M[__TR-!=$;``!(C17@%```2(TU(1H``$4QR4B)QTB#Q`A,B<'I=][__P\?
M@`````!54TB!["@@``!D2(L$)2@```!(B80D&"```#'`2(GC2(VL)!`0``#H
M%-S__TR-#;49``!(C0WC&0``08G`N@$0``"^`0```$B)WS'`Z!_?__^Z`!``
M`$B)[DB)W^B_V___A<!X4XUX`4B)PTAC_^A]W?__2(7`2(G!=!A(8]M(B>Y(
MB<=(B=KH--W__TB)P<8$&`!(BY0D&"```&1(,Q0E*````$B)R'432('$*"``
M`%M=PP\?1```,<GKU^C_V___9F8N#Q^$```````/'T``Z2O___]F9BX/'X0`
M`````$%7059!54%428GT55-(B?M(C3TR&0``2('L*!```&1(BP0E*````$B)
MA"08$```,<!(C70D#.C%]___OB\```!(B=](B<7HM=O__TB%P'1`2(T]^Q@`
M`$B)WC'`Z/_X__](B=A(BXPD&!```&1(,PPE*`````^%F@$``$B!Q"@0``!;
M74%<05U!7D%?PP\?`$B)W^@XV___2(TUP!@``$R)YT&)Q>A6W?__2(7`28G'
M=)Y!@\4!08`_`$R-9"003(TUFQ@```^$X@````\?0`!(A>UT$TR)_DB)[^C0
MV___A<`/A*(```!,B?_HX-K__XG"2)A!@'P'_R]U%P\?0`"#Z@%(8\)!@'P'
M_R]!Q@0'`'3M1`'J@?K_#P``#X\N____2(/L"$B-#5,9``!-B?%338GXN@`0
M``"^`0```$R)YS'`Z$C=__^+/0)N(`#HK=O__TB-D``"``!,B>:_`0```.@)
MVO__A<!:674=BSW=;2``Z(C;__^+@!@"```E`/```#T`@```=%Y(C37.%P``
M,?_H:-S__TB%P$F)QP^$K/[__T&`/P`/A2+___](A>UT'4B-/3L7``"Y`@``
M`$B)[O.F#Y?`'`"$P'2]#Q\`3(T]'A<``+H!````Z3+___\/'X``````O@$`
M``!,B>?H^]O__X7`=9%(C3U2%P``3(GFZ%CW__],B>?H8-S__^E/_O__Z,;9
M__]F#Q]$```/MA=(B?B$TG0>9@\?1```2(/'`8#Z+P^V%T@/1,>$TG7N\\,/
M'T``\\-F#Q]$``!(A?\/A,\```!54TB#[`@/MB]`A.UT*4B)^^AAV?__2(U4
M`_](.=-R$.L[#Q]$``!(@^H!2#G3=#>`.B]T\NL=2(/$"$B-/5H6``!;7>G.
MV___9@\?1```@#HO=#A(@^H!2#G3<O)(.=-U*@\?1```0(#]+W3*2(/$"$B-
M/9`6``!;7>F8V___#Q^$``````"`.B]U"4B#Z@%(.=-R\D@IVDB-0@)(/0`0
M``!W.TB-/:QL(`!(@\(!N0`0``!(B=[H6]K__TB-!91L(`!(@\0(6UW##Q]$
M``!(C3W&%0``Z3S;__\/'T``,<#KX`\?0`!32(T]&Q8``$B#[$!D2(L$)2@`
M``!(B40D.#'`#[<%M1<``$B-7"0,\P]O!8@7```/*40D$&:)1"0P,<#S#V\%
MA!<```\I1"0@Z$+U__](C3W7%0``,<#H-/7__TB-/=$5```QP.@F]?__2(T]
MS!4``#'`Z!CU__](C3W%%0``,<#H"O7__TB-/<<5```QP.C\]/__2(T];A4`
M`#'`Z.[T__](C3VW%0``,<#HX/3__TB-/;,5```QP.C2]/__2(T]KQ4``#'`
MZ,3T__](C3T_%0``,<#HMO3__TB-/9T5```QP.BH]/__2(T]F!4``#'`Z)KT
M__](C3V5%0``,<!(B=[HN?/__TB%P'012(T]5Q4``$B)QC'`Z`/U__](C3U_
M%0``,<!(B=[HDO/__TB%P'012(T]>Q4``$B)QC'`Z-ST__](C3UU%0``,<!(
MB=[H:_/__TB%P'1&2(T]J!0``$B)QC'`Z+7T__](C35Z%0``2(T]RQ0``#'`
MZ*#T__](BT0D.&1(,P0E*````'5N2(/$0%O#9BX/'X0``````$B-/2D5```Q
MP$B)WN@/\___2(7`=3)(C70D(4B-/1\5``"Y"@```/.F#Y?`'`"$P'692(UT
M)"M(C3V"%```Z#WT___KA@\?`$B-/7$4``!(B<8QP.@G]/__Z6W____HG=;_
M_V9F+@\?A```````9I!(@^P89$B+!"4H````2(E$)`@QP(L%QFD@`(/X_W09
M2(M\)`AD2#,\)2@```!U0$B#Q!C##Q]``$B-="0$2(T]#!0``#'`Z&7R__](
MB<(QP$B%TG02#[82@/HP#Y7!,<"$T@^5P"'(B05S:2``Z[#H'-;__V9F+@\?
MA```````D$B#[`CH%];__XG'Z,#5__](A<!T"TB+`$B#Q`C##Q\`,<#K]&9F
M+@\?A```````D$%7059!54%428G]55-(C2TD%```2(T=$Q0``$B#[&AD2(L$
M)2@```!(B40D6#'`2(T%!10``$B);"0@2(E<)"A(QT0D4`````!,C60D($R-
M="0<2(E$)#!(C072$P``2(E$)#A(C07+$P``2(E$)$!(C071$P``2(E$)$CK
M(&:02(G'Z/C7__](A<!T:TF#Q`A(A=MT.$B)W4F+7"0(3(GV,<!(B>_H5?'_
M_TB%P$F)QTR)[G0%@#@`=<4QP$B)[TF#Q`CHE_+__TB%VW7(2(M$)%AD2#,$
M)2@````/A84```!(@\1H6UU!7$%=05Y!7\,/'X``````3(GOZ-#4__],B?](
MB40D".C#U/__2(M,)`A(C7P!`NCTU?__2(/L"$R-#3@2``!(C0U2$P``05=(
MQ\+_____2(G'38GHO@$```!(B40D&#'`Z$+7__],BU0D&$B)[S'`3(G6Z`#R
M__]86NDF____Z'34__\/'T``05=!5D%5051)B?U54TB-/<41``!(@>R(@0``
M9$B+!"4H````2(F$)'B!```QP$B-!;H2``!,C60D+$C'1"1``````$C'A"28
M`````````$C'1"1@`````$B)1"0P2(T%(1$``$R)YDB)1"0X2(T%$A(``$B)
M1"1P2(T%_Q$``$B)1"1X2(T%:1(``$B)A"2`````2(T%`1(``$B)A"2(````
M2(T%4Q(``$B)A"20````2(T%*Q(``$B)1"102(T%/!(``$B)1"18,<#HP.__
M_TB%P'0)@#@`#X52`@``,<#H>_W__TB%P$B)PP^$CP(``$B)W^AGT___2(U\
M``'HG=3__X`[`$F)QG0W3(T]]Q$``$R)]0\?`$0/M@-(B>\QP$R)^4C'PO__
M__^^`0```$B#PP%(@\4"Z./5__^`.P!UUDB-7"1P2(T]-Q$``.L02(/#"$B+
M.TB%_P^$>`$``#'`3(GFZ";O__](A<!(B<5TWH`X`'392(G'Z$'T__^%P'3-
M2(GOZ'75__](A<!)B<</A$$!``!F#Q^$``````!,B?J+"DB#P@2-@?_^_O[W
MT2'()8"`@(!TZ8G!P>D0J8"````/1,%(C4H"2`]$T8G!`,%,B?%(@]H#3"GZ
MBS%(@\$$C8;__O[^]]8A\"6`@("`=.F)QL'N$*F`@```#T3&2(UQ`D@/1,Z)
MQD``QDB#V0-,*?&-G`H$!```2&/;2(G?Z'G3__](B<5(C07F$```059,C0VW
M#P``2(T-S1```$V)^%!(Q\+_____O@$```!(B>\QP.C%U/__OL`!``!(B>_H
M6-'__X/X_T%805EU$N@:T?__1(L(08/Y$0^%V@@``(L]5V4@`.@"T___2(V0
M``(``$B)[K\!````Z![4__^%P$&)QP^$0P$``$F+30!(BSUH92``2(T501$`
M`$F)Z+X!````,<`QV^@@U/__ZWYF#Q]$```Q[68/'T0``$ACQ4B+7,0P2(7;
M=#N`.P!T-DB)WX/%`>C#\O__A<!TWTB)W^CWT___2(7`28G'#X6+_O__2&/%
M2(M<Q#!(A=MURV8/'T0``$4Q_^EP_O__2(G'2(D$).A4^___2(L$)$B)Q^BX
MT___2(G##Q]$``!(BXPD>($``&1(,PPE*````$B)V`^%]0@``$B!Q(B!``!;
M74%<05U!7D%?PP\?0`!(C3U<#P``,>U(A?]T)F:0,<!,B>:#Q0'H\^S__TB%
MP'0%@#@`=2E(8\5(BWS$4$B%_W7<OPT```!(C1TH#P``Z-O1__])B<;I/OW_
M_P\?`$B)Q^@HT___2(7`2(G##X4-_?__Z\%F+@\?A```````BSWJ8R``Z)71
M__^+@!@"```E`/```#T`0```#X6<_O__BSW)8R``Z'31__]$B[`<`@``Z%C0
M__]!.<8/A7S^__^+/:EC(`#H5-'__XN`&`(``"7_`0``/<`!```/A5O^__](
MB=_H1M'__TB-/6`.``!(B<-,B>8QP.@B[/__2(7`#X1I`0``2(G'Z('2__])
MBWT`2(G&Z`7T__](A<!)B<0/A$D!``!,B>?HP<___X/X`WX\2&/02(T];@X`
M`+D%````28UT%/SSI@^7PH#:`(32=1R#^`0/A`,&``"#Z`1(F$&`?`3_+P^$
M\@4``&:0,<#H^?C__X7`=14Q]DR)Y^A+T?__A<!!B<8/A?````!(C36U#0``
M2(T](@T``$R-)44.```QP$R-+=,,``#HS>S__^C(SO__051,C0W`#```4$B-
M#?P-``!(Q\+_____28GHO@$```!(B=\QP.C.T?__6%KK368N#Q^$``````#H
M*\[__X,X$75+Z('.__]!@\<!2(/L"$B-#<4-``!!5$%738GI4$F)Z$C'PO__
M__^^`0```$B)WS'`Z('1__](@\0@OL`!``!(B=_H$,[__X/X_W2K2(GOZ,/-
M__](C3T5#```2(G>,<#H(NS__TB)W^BZ^/__Z77]__\/'T0``$V+90#IKO[_
M_P\?@`````"Z`@```$C'QN[___^)Q^C=T/__2(V$)'`!``"Z!@```$2)]TB)
MQDB)!"3H$<___X"\)'`!````=0Z`O"1Q`0``0P^$D`4``#'2,?9$B??HG=#_
M_[B)J\WO3(VL)*````!(QX0DH`````$C16=(B80DJ````$@MB\X25TC'A"2X
M````=E0R$$B)A"2P````2`7R!!@K2,>$),@`````````2(F$),````!)C44X
M2,>$)-``````````QX0D&`$```````!(B40D"`\?A```````2(LT)+H`@```
M1(GWZ%_.__^%P$F)Q$&)P`^.<0$``$B+O"3(````26/$2(N4)-````"--,=(
M.?Y(B;0DR````$B#T@!(P>@=2`'02(F$)-````!(8X0D&`$``(7`#X0=`0``
M2(M,)`A!N$````!(BS0D02G`13G$10].Q$B-/`%)8]!)B==(B50D$.@@SO__
MBX0D&`$``$0!^(/X0(F$)!@!```/A5;___]%B>!,B>]%*?A,BWPD$$P#/"1$
MB40D'.CZTO__1(M$)!P/'T0``$&#^#]^>4&-0,")1"0<P>@&08G$B40D$$F#
MQ`%)P>0&30'\#Q]$``#S00]O!TR)[TF#QT`/$80DV````/-!#V]'T`\1A"3H
M````\T$/;T?@#Q&$)/@```#S00]O1_`/$80D"`$``.B%TO__33G\=;B+1"00
M1(M$)!S!X`9!*<!(BWPD"$ECT+E(````3(G^1(E$)!#H-\W__T2+1"001(F$
M)!@!``#IA?[__P\?1```3(L\).E'____#Q^``````$2)]^B(S/__3(ND),@`
M``!,B[0DT````$R)X$C!Z`.#X#^-4`%(F,:$!-@```"`@_HX#X^*`@``N#@`
M```Q]BG02&/2@_@(28U4%3@/@^,"``"H!`^%E@,``(7`=`NH`L8"``^%F@,`
M`$R)\$R)[T2(M"03`0``2,'H&$2(I"07`0``3(VL)$`!``"(A"00`0``3(GP
M2,'H$(B$)!$!``!,B?!,C34/"@``2,'H"(B$)!(!``!,B>!(P>@8B(0D%`$`
M`$R)X$C!Z!"(A"05`0``3(G@13'D2,'H"(B$)!8!``#H2='__TB+A"2@````
M2(G"B(0D(P$``$C!ZAA$#[;"B)0D(`$``$B)PDC!ZA"(E"0A`0``2(G"2(N$
M)*@```!(P>H(B)0D(@$``$B)PHB$)"<!``!(P>H8B)0D)`$``$B)PDC!ZA"(
ME"0E`0``2(G"2(N$)+````!(P>H(B)0D)@$``$B)PHB$)"L!``!(P>H8B)0D
M*`$``$B)PDC!ZA"(E"0I`0``2(G"2(N$)+@```!(P>H(B)0D*@$``$B)PHB$
M)"\!``!(P>H8B)0D+`$``$B)PDC!ZA"(E"0M`0``2(G"2(N$),````!(P>H(
MB)0D+@$``$B)PHB$)#,!``!(P>H8B)0D,`$``$B)PDC!ZA"(E"0Q`0``2(G"
M2,'J"(B4)#(!``#I#`````\?`$8/MH0D(`$``$N-?&4`,<!,B?%(Q\+_____
MO@$```!)@\0!Z)C,__])@_P4==)(C07%"```QH0D:`$```!0055(C0U_"```
M3(T-0P<``+X!````28GH2,?"_____TB)WS'`Z%G,__]97NGG^O__9I!-BVT(
M387M#X0#^O__3(GOZ'O)__](@_@##X;Q^?__28UT!?Q(C3TF"```N04```#S
MI@^7P!P`A,!-#T3EZ<[Y__^X0````$ACRBG028U,#3AT#S'2B=:#P@$YPL8$
M,0!R\TR)[^A&S___9@_OP`\1A"38````2<=%:`````!!#Q%%2$$/$458Z5S]
M__])BTT`2(L]N%P@`$B-%5$(``!)B>B^`0```#'`,=OH<,O__^G+]___B<%(
MQP(`````2,=$"O@`````2(U*"$B#X?A(*<H!T(/@^(/X"`^""?W__X/@^#'2
MB=>#P@@YPDB)-#ER\^GR_/__@+PD<@$``$$/A6+Z__^`O"1S`0``0P^%5/K_
M_X"\)'0!``!(#X5&^O__@+PD=0$``$4/A3CZ__^Z`@```$C'QL;___]$B??H
MS<K__TR+/"2Z*0```$2)]TR)_N@)R?__2(T%+`<``%!!5^EJ_O__9BX/'X0`
M`````,<"`````,=$`OP`````Z6;\__\Q_V:)?`+^Z5K\___H#,C__V9F+@\?
MA```````D$%7059!54%455-(@^P8BSU<6R``9$B+!"4H````2(E$)`@QP$R-
M;"0$Z/+(__^+/3Q;(`!(B</HY,C__P^VD[@```!(C3U:!0``3(GNB)"Y````
M,<#HQN/__TB%P'0)@#@Q#X0(`P``,<#H\>[__XL]^UH@`.BFR/__2(TU8P8`
M`+D+````N@$```!(B<?H3<C__TB%P`^$Q````(,]/6L@``%(BT`01(LUPEH@
M`$R+8"@/CJ\````Q[;L!````ZSH/'X``````28MW$$B+!05K(`!(8]-(BSS0
MZ/''__^%P(L5^6H@``^%"`(``(/#`8/%`3G3#XWZ`0``1(GWZ!W(__\QR4AC
MU4R)YDB)Q^CMR/__2(7`#X3,`0``3(LX1(LU2EH@`$&+1PPE``0@`#T`!```
M=))$B??HXL?__TR)_KD"````,=)(B<?H`,?__T2+-1E:(`!(B<;I;?___Y!$
MBS4)6B``1(GWZ+''__](C35S!0``N0,```"Z`0```$B)Q^A8Q___2(7`2(G#
M=#5(BT`0BSW662``2(LHZ'['__](C15"!0``2(G'2(GNZ(S&__](BT,02(L8
M]D,.0`^%ZP$``(L]I5D@`.A0Q___2(TU&00``+D#````N@$```!(B<?H]\;_
M_TB%P$B)PW0]2(T]>@,``#'`3(GNZ![B__](A<!(B<4/A'(!``!(BT,0BSU8
M62``2(L8Z`#'__](B>I(B<=(B=[H$L;__XL]/%D@`.CGQO__2(TUL`0``+H!
M````2(G'Z//&__^+/1U9(`!(B</HQ<;__TB-%:,$``!(B=Y(B<?HT\7__XL]
M_5@@`.BHQO__2(T]Z@(``,:`N0````!,B>XQP.B0X?__2(7`2(G#2(D%2VD@
M``^$G0```+[``0``2(G?Z*#$__^-4`&#^@%V"8/X$0^%#P$``$B+1"0(9$@S
M!"4H````#X7V````2(/$&%M=05Q!74%>05_##Q]``(L5\F@@`$2+-7M8(`"-
M0O\YZ`^%9_[__X/Z`0^.7O[__[L!````9I!$B?>#PP'H!<;__TR)YDB)Q^A*
MQ/__.1VT:"``1(LU/5@@`'_;Z2W^__]F#Q]$``!(BSV1:"``Z$3P__](A<!(
MB<-(B06/:"``#X5$____2(T]@@0``#'`Z./%__\/'P"`>`$`#X3U_/__Z>G\
M__^02(L%46@@`(L]XU<@`$B+*$B+0Q!(BQCHA,7__TB)[DB)W^@YYO__Z8+^
M__\/'T``BSVZ5R``Z&7%__](B=Y(B<?HNL7__^GZ_?__Z##$__^)P4B+!?]G
M(`!(C3TP!```2(G:2(LP,<#H8\7__P\?`%532(G]2(/L".ARZO__#[802(G#
MA-)T&@\?A```````2(/``8#Z+P^V$$@/1-B$TG7N,<#H1^W__TB%[70DA<!T
M((!]``!T&DB-/6@"``"Y!````$B)WO.F#Y?`'`"$P'0'2(/$"%M=PTB#Q`A(
MB>];7>EIX___9@\?A```````2(T%T58@`#')2(7`=`-(BPCI"L3__V8N#Q^$
M``````!!5T%628G7055!5$R-)1Y2(`!52(TM'E(@`%-!B?U)B?9,*>5(@^P(
M2,']`^@GPO__2(7M="`QVP\?A```````3(GZ3(GV1(GO0?\4W$B#PP%(.=UU
MZDB#Q`A;74%<05U!7D%?PV9F+@\?A```````\\,``$B#[`A(@\0(PP````$`
M`@`N+@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R.CIB;V]T7T1Y
M;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`4$%2
M7U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU
M3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,
M14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%27T%21U9?,`!0
M05)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q
M`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`4TA,24)?4$%42`!54T52`%-9
M4U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`)7,E<R5S)7,`
M<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`%!!4CHZ4&%C:V5R.CI615)3
M24].`#$N,#,V`"UE`"TM``````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@(```````````<&5R;'AS:2YC`````````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E
M("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*
M````````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG
M('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E
M;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I
M;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R
M7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@
M)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H
M"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+
M(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@
M7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M
M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP
M<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB
M.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^
M9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*
M<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C
M97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*
M?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN
M960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N
M=B@I.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%2
M7T%21U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL
M("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P(#T@)$5.5GM005)?05)'
M5E\P?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I('L*9&5L971E("1%3E9[
M)%]](&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@
M/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/
M(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?
M9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G
M+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@
M*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?
M7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T
M.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N
M86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q
M*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@
M7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P
M<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O
M9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=
M('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F
M+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T
M(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H]
M(#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@
M+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T
M.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*
M<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T
M.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI
M;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA
M;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H
M)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN
M+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^
M("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M
M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@
M)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA
M;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<
M;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2
M.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B
M=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I
M<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]
M("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E
M9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R
M:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B
M)&9I;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N
M(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F
M:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE
M(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<
M;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I
M<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES
M("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65]
M(&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^
M("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O
M("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE
M7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*
M?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O
M<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L
M("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM0
M05)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C
M=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"
M54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO
M<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B
M;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*
M<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@
M)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!
M4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L
M('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I
M('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@
M;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@
M*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@
M>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U
M;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@
M,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D
M,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@
M*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6
M*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6
M>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ
M1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T
M($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D
M9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B
M.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D
M:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!
M4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD[
M"F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q
M(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/
M.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W
M-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D
M9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@
M,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@
M;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[
M"FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*
M;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E
M<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL
M96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE
M<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B
M:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O
M;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<
M15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R
M*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<
M6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE
M;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER
M+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N
M86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J
M;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL
M93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO
M<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N
M86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D[
M"GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B
M1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT
M*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S
M:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\
M?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H
M)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L
M;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD
M:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M
M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12([
M"B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B
M7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE
M>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX
M7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY
M("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I
M+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.
M5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![
M(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M
M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES
M1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N
M86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE
M*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T
M7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI
M('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A
M;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T
M<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I
M<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U
M:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE
M9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E
M<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@
M7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$[
M"G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W
M*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64[
M"FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I
M("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@
M>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@
M)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM0
M05)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY
M72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L
M("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q
M(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@
M)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H
M,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ
M4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I
M9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$
M:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@
M97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^
M861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII
M9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN
M;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*
M?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T
M>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D[
M"GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S
M=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT
M96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O
M)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@
M/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE
M(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@
M)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M
M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP
M;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U
M<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN
M960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@
M/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@
M)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D
M14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R
M;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@
M,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H
M+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M
M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#
M;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L
M:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X
M="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM0
M05)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N
M86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*
M:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*
M)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]
M+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R
M7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q
M("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`]
M(#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%
M(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?
M)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@
M>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF
M(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE
M86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H
M)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE
M;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V
M86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB
M*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#
M3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*```````!&P,[[````!P```"H@?__
M.`$``&B%__]@`0``>(7__V`&``"HA___"`$``+B(__]X`0``R)[__\@!``"8
MG___%`(``"B@__]``@``>*+__XP"``#XH___V`(``(BD___X`@``:*7__SP#
M``"8I?__5`,``.BE__]L`P``N*;__Y@#``#(IO__K`,``.BH__\,!```&*G_
M_R`$```(JO__<`0``!BL__^4!```F*S__[`$``#(K/__S`0``#BN__\H!0``
MJ+K__^`%``"8OO__+`8``!B___^0!@``.+___Z@&``"HO___\`8````````4
M``````````%Z4@`!>!`!&PP'")`!!Q`4````'````)B&__\K````````````
M```4``````````%Z4@`!>!`!&PP'")`!```D````'````&B`___``P````X0
M1@X82@\+=PB``#\:.RHS)"(`````%````$0`````A/__"```````````````
M3````%P````XA___#A8```!"#A"/`D(.&(X#1@X@C01"#BB,!40.,(8&00XX
M@P='#M`%`^85"@XX00XP00XH0@X@0@X80@X00@X(00L```!(````K````/B<
M___,`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX
M1`XP00XH0@X@0@X80@X00@X(20L`*````/@```!\G?__A`````!!#A"&`D$.
M&(,#1PXP`G,*#AA!#A!!#@A!"P!(````)`$``."=__],`@```$(.$(\"0@X8
MC@-"#B"-!$(.*(P%00XPA@9!#CB#!TH.8`,F`0H..$$.,$$.*$(.($(.&$(.
M$$(."$0+2````'`!``#DG___>0$```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P='#O`!?@H..$$.,$$.*$(.($(.&$(.$$(."$<+`!P```"\`0``
M&*'__X$`````00X0@P)I"@X(1@L"4`X(0````-P!``"(H?__W@````!"#A".
M`D(.&(T#10X@C`1!#BB&!40.,(,&4P[`(`*$"@XP00XH00X@0@X80@X00@X(
M0PL4````(`(``"2B__\P`````$0.$&<."``4````.`(``#RB__])`````$0.
M$'T."``H````4`(``'2B___!`````$$.$(8"00X8@P-'#L!``J<*#AA!#A!!
M#@A&"Q````!\`@``&*/__P4`````````7````)`"```4H___&@(```!"#A"/
M`D(.&(X#0@X@C01"#BB,!40.,(8&00XX@P=1#N`@`F0*#CA!#C!!#BA"#B!"
M#AA"#A!"#@A$"P*6#N@@2P[P('D.Z"!!#N`@````$````/`"``#4I/__*@``
M``````!,````!`,``/"D___L`````$H.$(8"00X8@P-$#B!U"@X82,,.$$'&
M#@A+"V(*#AA(PPX00<8."$T+`D`.&$$.$$$."$;#QE`.((,#A@(``"````!4
M`P``D*7__P,"````00X0@P)+#E`#B`$*#A!!#@A+"Q@```!X`P``?*?__W0`
M````1`X@;PH."$4+```8````E`,``."G__\D`````$0.$%@*#@A$"P``6```
M`+`#``#TI___;`$```!"#A"/`D(.&(X#0@X@C01"#BB,!40.,(8&00XX@P=2
M#J`!`L<*#CA!#C!!#BA"#B!"#AA"#A!"#@A("V@.J`%0#K`!<0ZH`4$.H`&T
M````#`0```BI__]D#````$(.$(\"0@X8C@-"#B"-!$(.*(P%1`XPA@9!#CB#
M!TX.P(,"`Q@"#LB#`E(.T(,":`[(@P)"#L"#`@,"`0H..$$.,$$.*$(.($(.
M&$(.$$(."$4+`ZH!#LB#`D@.T(,"80[(@P)!#L"#`F,.R(,"20[0@P)"#MB#
M`D0.X(,"70[`@P(#^P0.R(,"0@[0@P)H#LB#`D$.P(,"`V8!"@[(@P)"#M"#
M`D\+2````,0$``#`M/__[0,```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&
M00XX@P=$#E`#RP(*#CA!#C!!#BA"#B!"#AA"#A!"#@A%"S`````0!0``9+C_
M_W<`````00X0A@)!#AB#`T<.(`)="@X800X000X(00M$#AA$#A!!#@@L````
M1`4``!!___\M`@```$$.$(8"00X8@P-$#E`#O0$*#AA!#A!!#@A!"P`````4
M````=`4``("X__\6``````````````!$````C`4``(BX__]E`````$(.$(\"
M0@X8C@-%#B"-!$(.*(P%2`XPA@9(#CB#!TT.0'(..$$.,$$.*$(.($(.&$(.
M$$(."``0````U`4``+"X__\"````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````L"0```````!P)```````
M``````````````````````````````````$``````````0`````````!````
M`````,8!`````````0`````````5`@```````!T`````````Q`0````````,
M`````````)@=````````#0````````"T6P```````!D`````````<*T@````
M```;``````````@`````````&@````````!XK2```````!P`````````"```
M```````$`````````)@"````````]?[_;P````"X!0````````4`````````
M,!`````````&`````````+@&````````"@````````#Y!`````````L`````
M````&``````````5`````````````````````P``````````L"````````(`
M````````B`4````````4``````````<`````````%P`````````0&```````
M``<`````````>!8````````(`````````)@!````````"0`````````8````
M`````/O__V\`````````"`````#^__]O`````/@5````````____;P`````"
M`````````/#__V\`````*A4```````#Y__]O``````0`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"8K2````````````````````````````#&'0```````-8=
M````````YAT```````#V'0````````8>````````%AX````````F'@``````
M`#8>````````1AX```````!6'@```````&8>````````=AX```````"&'@``
M`````)8>````````IAX```````"V'@```````,8>````````UAX```````#F
M'@```````/8>````````!A\````````6'P```````"8?````````-A\`````
M``!&'P```````%8?````````9A\```````!V'P```````(8?````````EA\`
M``````"F'P```````+8?````````QA\```````#6'P```````.8?````````
M]A\````````&(````````!8@````````)B`````````V(````````$8@````
M````5B````````!F(````````'8@````````AB````````"6(````````*8@
M````````MB````````#&(````````-8@````````YB````````#V(```````
M``8A````````%B$````````F(0```````#8A````````1B$```````!6(0``
M`````&8A``````````````````#XL2```````/____\`````"%\```````!'
M0T,Z("A355-%($QI;G5X*2`W+C0N,```+G-H<W1R=&%B`"YI;G1E<G``+FYO
M=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS
M>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N
M9'EN`"YR96QA+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D
M871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI
M7V%R<F%Y`"YD871A+G)E;"YR;P`N9'EN86UI8P`N9V]T+G!L=``N9&%T80`N
M8G-S`"YC;VUM96YT````````````````````````````````````````````
M````````````````````````````````````````````````"P````$````"
M`````````#@"````````.`(````````<`````````````````````0``````
M`````````````!,````'`````@````````!4`@```````%0"````````(```
M``````````````````0````````````````````A````!P````(`````````
M=`(```````!T`@```````"0````````````````````$````````````````
M````.`````4````"`````````)@"````````F`(````````@`P````````8`
M````````"``````````$`````````#0```#V__]O`@````````"X!0``````
M`+@%````````_``````````&``````````@````````````````````^````
M"P````(`````````N`8```````"X!@```````'@)````````!P````$````(
M`````````!@`````````1@````,````"`````````#`0````````,!``````
M``#Y!````````````````````0```````````````````$X```#___]O`@``
M```````J%0```````"H5````````R@`````````&``````````(`````````
M`@````````!;````_O__;P(`````````^!4```````#X%0```````(``````
M````!P````(````(````````````````````:@````0````"`````````'@6
M````````>!8```````"8`0````````8`````````"``````````8````````
M`'0````$````0@`````````0&````````!`8````````B`4````````&````
M&0````@`````````&`````````!^`````0````8`````````F!T```````"8
M'0```````!<````````````````````$````````````````````>0````$`
M```&`````````+`=````````L!T```````#``P``````````````````$```
M```````0`````````(0````!````!@````````!P(0```````'`A````````
M"`````````````````````@`````````"`````````"-`````0````8`````
M````@"$```````"`(0```````#(Z```````````````````0````````````
M````````DP````$````&`````````+1;````````M%L````````)````````
M````````````!````````````````````)D````!`````@````````#`6P``
M`````,!;````````2$````````````````````@```````````````````"A
M`````0````(`````````")P````````(G````````.P`````````````````
M```$````````````````````KP````$````"`````````/B<````````^)P`
M```````8!@``````````````````"````````````````````+D````.````
M`P````````!PK2```````'"M````````"`````````````````````@`````
M````"`````````#%````#P````,`````````>*T@``````!XK0````````@`
M```````````````````(``````````@`````````T0````$````#````````
M`("M(```````@*T````````3````````````````````$```````````````
M`````-X````&`````P````````"8K2```````)BM````````(`(````````'
M``````````@`````````$`````````"(`````0````,`````````N*\@````
M``"XKP```````$`````````````````````(``````````@`````````YP``
M``$````#``````````"P(````````+````````#P`0``````````````````
M"``````````(`````````/`````!`````P````````#PL2```````/"Q````
M````(`````````````````````@```````````````````#V````"`````,`
M````````(+(@```````0L@```````(@0```````````````````@````````
M````````````^P````$````P````````````````````$+(````````8````
M`````````````````0`````````!``````````$````#````````````````
M`````````"BR````````!`$```````````````````$`````````````````
"````
